@@ -209,8 +209,9 @@ static MagickBooleanType IsWEBPImageLossless(const unsigned char *stream,
   return(MagickFalse);
 }
 
-static int FillBasicWEBPInfo(Image *image, const uint8_t *stream,
-			size_t length, WebPDecoderConfig *configure){
+static int FillBasicWEBPInfo(Image *image,const uint8_t *stream,size_t length,
+  WebPDecoderConfig *configure)
+{
   WebPBitstreamFeatures
     *magick_restrict features = &configure->input;
 
@@ -230,8 +231,9 @@ static int FillBasicWEBPInfo(Image *image, const uint8_t *stream,
   return webp_status;
 }
 
-static int ReadSingleWEBPImage(Image *image, const uint8_t *stream, size_t length,
-			   WebPDecoderConfig *configure, ExceptionInfo *exception){
+static int ReadSingleWEBPImage(Image *image,const uint8_t *stream,
+  size_t length,WebPDecoderConfig *configure,ExceptionInfo *exception)
+{
   int
     webp_status;
 
@@ -275,7 +277,7 @@ static int ReadSingleWEBPImage(Image *image, const uint8_t *stream, size_t lengt
       SetPixelRed(q,ScaleCharToQuantum(*p++));
       SetPixelGreen(q,ScaleCharToQuantum(*p++));
       SetPixelBlue(q,ScaleCharToQuantum(*p++));
-      SetPixelOpacity(q,ScaleCharToQuantum(*p++));
+      SetPixelAlpha(q,ScaleCharToQuantum(*p++));
       q++;
     }
     if (SyncAuthenticPixels(image,exception) == MagickFalse)
@@ -344,9 +346,10 @@ static int ReadSingleWEBPImage(Image *image, const uint8_t *stream, size_t lengt
 }
 
 #if defined(MAGICKCORE_WEBPMUX_DELEGATE)
-static int ReadAnimatedWEBPImage(const ImageInfo *image_info, Image *image,
-	uint8_t *stream, size_t length, WebPDecoderConfig *configure,
-	ExceptionInfo *exception) {
+static int ReadAnimatedWEBPImage(const ImageInfo *image_info,Image *image,
+  uint8_t *stream,size_t length,WebPDecoderConfig *configure,
+  ExceptionInfo *exception)
+{
   WebPData data = {.bytes=stream, .size=length};
 
   WebPDemuxer* demux = WebPDemux(&data);
@@ -568,7 +571,7 @@ static Image *ReadWEBPImage(const ImageInfo *image_info,
 ModuleExport size_t RegisterWEBPImage(void)
 {
   char
-    version[MaxTextExtent];
+    version[MagickPathExtent];
 
   MagickInfo
     *entry;
@@ -578,7 +581,7 @@ ModuleExport size_t RegisterWEBPImage(void)
 #if defined(MAGICKCORE_WEBP_DELEGATE)
   entry->decoder=(DecodeImageHandler *) ReadWEBPImage;
   entry->encoder=(EncodeImageHandler *) WriteWEBPImage;
-  (void) FormatLocaleString(version,MaxTextExtent,"libwebp %d.%d.%d [%04X]",
+  (void) FormatLocaleString(version,MagickPathExtent,"libwebp %d.%d.%d [%04X]",
     (WebPGetEncoderVersion() >> 16) & 0xff,
     (WebPGetEncoderVersion() >> 8) & 0xff,
     (WebPGetEncoderVersion() >> 0) & 0xff,WEBP_ENCODER_ABI_VERSION);
@@ -691,8 +694,9 @@ static void FreePictureMemoryList (PictureMemory* head) {
   }
 }
 
-static MagickBooleanType WriteSingleWEBPImage(const ImageInfo *image_info, Image *image,
-  WebPPicture *picture, PictureMemory *picture_memory, ExceptionInfo *exception)
+static MagickBooleanType WriteSingleWEBPImage(const ImageInfo *image_info,
+  Image *image,WebPPicture *picture,PictureMemory *picture_memory,
+  ExceptionInfo *exception)
 {
   MagickBooleanType
     status = MagickFalse;
@@ -740,7 +744,7 @@ static MagickBooleanType WriteSingleWEBPImage(const ImageInfo *image_info, Image
     for (x=0; x < (ssize_t) image->columns; x++)
     {
       *q++=(uint32_t) (image->matte != MagickFalse ? (uint32_t)
-        ScaleQuantumToChar(GetPixelOpacity(p)) << 24 : 0xff000000) |
+        ScaleQuantumToChar(GetPixelAlpha(p)) << 24 : 0xff000000) |
         ((uint32_t) ScaleQuantumToChar(GetPixelRed(p)) << 16) |
         ((uint32_t) ScaleQuantumToChar(GetPixelGreen(p)) << 8) |
         ((uint32_t) ScaleQuantumToChar(GetPixelBlue(p)));
@@ -756,8 +760,8 @@ static MagickBooleanType WriteSingleWEBPImage(const ImageInfo *image_info, Image
 
 #if defined(MAGICKCORE_WEBPMUX_DELEGATE)
 static MagickBooleanType WriteAnimatedWEBPImage(const ImageInfo *image_info,
-		Image *image, WebPConfig *configure,
-		WebPMemoryWriter *writer_info, ExceptionInfo *exception)
+  Image *image, WebPConfig *configure,WebPMemoryWriter *writer_info,
+  ExceptionInfo *exception)
 {
   WebPAnimEncoderOptions
 	  enc_options;
